.. :changelog:

History
-------

1.0 (2014-05-20)
++++++++++++++++++

* First release as a module. Packaged for pypi by Henrique Pereira. Uploaded
  to pypi

1.1 (2014-05-21)
++++++++++++++++++

* Proper initialization of curses colors and hide terminal cursor, by
  Crys Seymour

1.2 (2014-05-21)
++++++++++++++++

* Added support for 256 color terminals mimicking the original web game

1.3 (2014-05-22)
++++++++++++++++

* Adapt tile height to terminal window height and adjust dynamically if
  resized
